@@ -32,13 +32,16 @@
 #ident	"@(#)sccs:cmd/admin.c"
 
 # include	<defines.h>
-#include	<schily/standard.h>	/* define signed */
 # include	<had.h>
 # include	<i18n.h>
-# include	<dirent.h>
+# include	<schily/dirent.h>
 # include	<setjmp.h>
 # include	<sys/utsname.h>
-# include	<sys/wait.h>
+# include	<schily/wait.h>
+
+#ifdef	NEED_O_BINARY
+#include <io.h>			/* for setmode() prototype */
+#endif
 
 /*
 	Program to create new SCCS files and change parameters
@@ -139,7 +142,7 @@ extern int	org_ihash;
 extern int	org_chash;
 extern int	org_uchash;
 
-extern char	*saveid;
+extern char	saveid[];
 
 int
 main(argc,argv)
@@ -163,8 +166,13 @@ char *argv[];
 	/* 
 	 * Set directory to search for general l10n SCCS messages.
 	 */
+#ifdef	PROTOTYPES
+	bindtextdomain(NOGETTEXT("SUNW_SPRO_SCCS"),
+	   NOGETTEXT(INS_BASE "/ccs/lib/locale/"));
+#else
 	bindtextdomain(NOGETTEXT("SUNW_SPRO_SCCS"),
 	   NOGETTEXT("/usr/ccs/lib/locale/"));
+#endif
 	
 	textdomain(NOGETTEXT("SUNW_SPRO_SCCS"));
 
@@ -651,16 +659,21 @@ char	*afile;
 	
 
 	else {
+		FILE	*xf;
+
 		if ((int) strlen(sname(afile)) > MAXNAMLEN) {
 			sprintf(SccsError, gettext("file name is greater than %d characters"),
 				MAXNAMLEN);
 			fatal(SccsError);
 		}
 		if (exists(auxf(afile,'g')) && (S_IEXEC & Statbuf.st_mode)) {
-			xfcreat(afile,0555);	/* create dummy s-file */
+			xf = xfcreat(afile,0555);	/* create dummy s-file */
 		} else {
-			xfcreat(afile,0444);	/* create dummy s-file */
+			xf = xfcreat(afile,0444);	/* create dummy s-file */
 		}
+		if (xf)			/* XXX Closing is needed on Cygwin   */
+			fclose(xf);	/* XXX to avoid an EPERM in rename() */
+
 		sinit(&gpkt,afile,0);	/* and init pkt */
 	}
 
@@ -986,7 +999,7 @@ char	*afile;
 	if (HADT) {
 		if (tfile) {
 		   if (*tfile) {
-			iptr = xfopen(tfile,0);
+			iptr = xfopen(tfile, O_RDONLY|O_BINARY);
 			(void)fgetchk(iptr, tfile, &gpkt, 0);
 			fclose(iptr);
 			iptr = NULL;
@@ -1045,14 +1058,17 @@ char	*afile;
 				strcpy(stdin_file_buf, "/tmp/admin.XXXXXX");
 				cur_umask = umask((mode_t)((S_IRWXU|S_IRWXG|S_IRWXO)&~(S_IRUSR|S_IWUSR)));
 #ifdef	HAVE_MKSTEMP
-				if ((out = fdopen(mkstemp(ifile), "w")) == NULL) {
+				if ((out = fdopen(mkstemp(ifile), "wb")) == NULL) {
 					xmsg(ifile, NOGETTEXT("admin"));
 				}
 #else
 				mktemp(stdin_file_buf);
-				if ((out = fopen(ifile, "w")) == NULL) {
+				if ((out = fopen(ifile, "wb")) == NULL) {
 					xmsg(ifile, NOGETTEXT("admin"));
 				}
+#endif
+#ifdef	NEED_O_BINARY
+				setmode(fileno(out), O_BINARY);
 #endif
 				(void)umask(cur_umask);
 				/*CONSTCOND*/
@@ -1076,7 +1092,7 @@ char	*afile;
 				}
 				fclose(out);
 			   }
-			   iptr = xfopen(ifile,0);
+			   iptr = xfopen(ifile, O_RDONLY|O_BINARY);
 			}
 
 			/* save an offset to x-file in case need to encode
@@ -1461,12 +1477,12 @@ struct packet *gpkt;
 	if (!HADB)
 		fprintf(stderr, gettext("Not a text file (ad32)\n"));
 	rewind(iptr);
-	eptr = fopen(auxf(afile,'e'),"w");
+	eptr = fopen(auxf(afile,'e'), "wb");
 
 	encode(iptr,eptr);
 	fclose(eptr);
 	fclose(iptr);
-	iptr = fopen(auxf(afile,'e'),"r");
+	iptr = fopen(auxf(afile,'e'), "rb");
 	/* close the stream to xfile and reopen it at offset.  Offset is
 	 * the end of sccs header info and before gfile contents
 	 */
