@@ -33,7 +33,11 @@
 #include	<defines.h>
 #include	<i18n.h>
 
+#ifdef	PROTOTYPES
+static unsigned char Ohelpcmd[] = NOGETTEXT(INS_BASE "/ccs/lib/help/lib/help2");
+#else
 static unsigned char Ohelpcmd[] = NOGETTEXT("/usr/ccs/lib/help/lib/help2");
+#endif
 
 int main __PR((int argc, char **argv));
 
@@ -53,8 +57,13 @@ char *argv[];
 	 * Note this is not the same directory tree as that for the
 	 * help text above.
 	 */
+#ifdef	PROTOTYPES
+	bindtextdomain(NOGETTEXT("SUNW_SPRO_SCCS"),
+	   NOGETTEXT(INS_BASE "/ccs/lib/locale/"));
+#else
 	bindtextdomain(NOGETTEXT("SUNW_SPRO_SCCS"),
 	   NOGETTEXT("/usr/ccs/lib/locale/"));
+#endif
 	
 	textdomain(NOGETTEXT("SUNW_SPRO_SCCS"));
 
