@@ -87,13 +87,21 @@
 	If the argument is omitted, the program requests it.
 */
 
+#ifdef	PROTOTYPES
+#define HELPLOC INS_BASE "/ccs/lib/help/helploc"
+#else
 #define HELPLOC "/usr/ccs/lib/help/helploc"
+#endif
 
 /* char	dftfile[]   =   "/usr/ccs/lib/help/default"; */
 /* char	helpdir[]   =   "/usr/ccs/lib/help/"; */
 
 static char dftfile[] = NOGETTEXT("/default");
+#ifdef	PROTOTYPES
+static char helpdir[] = NOGETTEXT(INS_BASE "/ccs/lib/help/locale/");
+#else
 static char helpdir[] = NOGETTEXT("/usr/ccs/lib/help/locale/");
+#endif
 
 char	SccsError[MAXERRORLEN];
 static char	hfile[256];
@@ -140,8 +148,13 @@ char *argv[];
 	/* 
 	 * Set directory to search for general l10n SCCS messages.
 	 */
+#ifdef	PROTOTYPES
+	bindtextdomain(NOGETTEXT("SUNW_SPRO_SCCS"),
+	   NOGETTEXT(INS_BASE "/ccs/lib/locale/"));
+#else
 	bindtextdomain(NOGETTEXT("SUNW_SPRO_SCCS"),
 	   NOGETTEXT("/usr/ccs/lib/locale/"));
+#endif
 	textdomain(NOGETTEXT("SUNW_SPRO_SCCS"));
 
 	Fflags = FTLMSG;
