@@ -60,7 +60,11 @@
 # include 	<defines.h>
 # include	<had.h>
 # include	<i18n.h>
-# include	<sys/wait.h>
+# include	<schily/wait.h>
+
+#ifdef	NEED_O_BINARY
+#include <io.h>			/* for setmode() prototype */
+#endif
 
 struct stat Statbuf;
 char Null[1];
@@ -144,8 +148,13 @@ char *argv[];
 	/* 
 	 * Set directory to search for general l10n SCCS messages.
 	 */
+#ifdef	PROTOTYPES
+	bindtextdomain(NOGETTEXT("SUNW_SPRO_SCCS"),
+	   NOGETTEXT(INS_BASE "/ccs/lib/locale/"));
+#else
 	bindtextdomain(NOGETTEXT("SUNW_SPRO_SCCS"),
 	   NOGETTEXT("/usr/ccs/lib/locale/"));
+#endif
 
 	textdomain(NOGETTEXT("SUNW_SPRO_SCCS"));
 
@@ -1122,9 +1131,13 @@ char	*file;
 				/* umask 0133 -> create mode 0644 */
 	cur_umask = umask((mode_t)((S_IRWXU|S_IRWXG|S_IRWXO)&~(S_IRUSR|S_IWUSR|S_IRGRP|S_IROTH)));
 #ifdef	HAVE_MKSTEMP
-	iop = fdfopen(mkstemp(file), 1);
+	iop = fdfopen(mkstemp(file), O_WRONLY|O_BINARY);
 #else
 	iop = xfcreat(mktemp(file), 0644);
+#endif
+#ifdef	NEED_O_BINARY
+	if (iop != NULL)
+		setmode(fileno(iop), O_BINARY);
 #endif
 	(void)umask(cur_umask);
 
@@ -1144,7 +1157,7 @@ register	char	*file;
 	register	char	*p;
 	FILE	*iop;
 
-	iop = xfopen(file,0);
+	iop = xfopen(file, O_RDONLY|O_BINARY);
 	while ((p = fgets(line,sizeof(line),iop)) != NULL)
 		printf("%s",p);
 	fclose(iop);
