@@ -134,8 +134,13 @@ char *argv[];
 	/* 
 	 * Set directory to search for general l10n SCCS messages.
 	 */
+#ifdef	PROTOTYPES
+	bindtextdomain(NOGETTEXT("SUNW_SPRO_SCCS"),
+	   NOGETTEXT(INS_BASE "/ccs/lib/locale/"));
+#else
 	bindtextdomain(NOGETTEXT("SUNW_SPRO_SCCS"),
 	   NOGETTEXT("/usr/ccs/lib/locale/"));
+#endif
 	
 	textdomain(NOGETTEXT("SUNW_SPRO_SCCS"));
 
@@ -315,11 +320,7 @@ char *file;
 #if defined(BUG_1205145) || defined(GMT_TIME)
 	time_t	tim;
 
-	struct timeb timeb;
-	ftime(&timeb);
 	tzset();
-	if (timezone == 0)
-		timezone = timeb.timezone * 60; 
 #endif
 
 	if (setjmp(Fjmp))	/* set up to return here from 'fatal' */
@@ -337,7 +338,7 @@ char *file;
 	if (HADS && HADI)
 		fatal(gettext("s and i conflict (pr1)"));
 
-	iptr = xfopen(file,0);
+	iptr = xfopen(file, O_RDONLY|O_BINARY);
 	linenum = 0;
 
 	p = lineread(NOEOF);
