@@ -123,8 +123,13 @@ char *argv[];
 	/* 
 	 * Set directory to search for general l10n SCCS messages.
 	 */
+#ifdef	PROTOTYPES
+	bindtextdomain(NOGETTEXT("SUNW_SPRO_SCCS"),
+	   NOGETTEXT(INS_BASE "/ccs/lib/locale/"));
+#else
 	bindtextdomain(NOGETTEXT("SUNW_SPRO_SCCS"),
 	   NOGETTEXT("/usr/ccs/lib/locale/"));
+#endif
 	
 	textdomain(NOGETTEXT("SUNW_SPRO_SCCS"));
 
@@ -770,7 +775,7 @@ msg(app,name,cmrs,stats,sids,fred)
 	 strcat(holdfred,NOGETTEXT("/termLOG"));
 	 if(stat(holdfred,&stbuf) == -1)
 		noexist = 1; /*new termLOG */
-	if(!(fd=fopen(holdfred,NOGETTEXT("a"))))
+	if(!(fd=fopen(holdfred, NOGETTEXT("ab"))))
 		{
 			fatal(gettext("CASSI msg not writable \n"));
 			return(0);
@@ -882,7 +887,7 @@ struct sid *sp;
 	char rline[BUFSIZ];
 	FILE *in;
 
-	in = xfopen(auxf(pkt->p_file,'p'),0);
+	in = xfopen(auxf(pkt->p_file,'p'), O_RDONLY|O_BINARY);
 	while (fgets(rline,sizeof(line),in) != NULL) {
 		pf_ab(rline,&pf,1);
 		if (sp->s_rel == pf.pf_gsid.s_rel &&
