@@ -28,18 +28,10 @@
 #ifndef lint
 static char sccsid[] = "@(#)sccs.c 1.2 2/27/90";
 #endif
-# include	<schily/mconfig.h>
-# include	<i18n.h>
 # include	<defines.h>
-#ifdef __STDC__
-# include	<stdlib.h>
-/*# include	<dirent.h>*/
+# include	<i18n.h>
 # include	<schily/dirent.h>
-# else 
-/*# include	<dirent.h>*/
-# include	<schily/dirent.h>
-#endif
-# include	<errno.h>
+# include	<schily/errno.h>
 # include	<signal.h>
 #ifdef __STDC__
 #define EX_OK 0
@@ -55,10 +47,14 @@ extern char *getlogin();
 extern char *getenv();
 #endif
 # include	<schily/varargs.h>
-# include	<sys/wait.h>
+# include	<schily/wait.h>
 # include	<pwd.h>
 
-static void get_list_files();
+#ifdef	NEED_O_BINARY
+#include <io.h>			/* for setmode() prototype */
+#endif
+
+/*static void get_list_files();*/
 static  char **diffs_np, **diffs_ap;
 
 int	Domrs;
@@ -162,11 +158,11 @@ char    Null[1];
 
 # ifndef SCCSPATH
 # define SCCSPATH	"SCCS"	/* pathname in which to find s-files */
-# endif NOT SCCSPATH
+# endif /* NOT SCCSPATH */
 
 # ifndef MYNAME
 # define MYNAME		"sccs"	/* name used for printing errors */
-# endif NOT MYNAME
+# endif /* NOT MYNAME */
 
 # ifdef DESTDIR
 # ifndef V6
@@ -195,33 +191,34 @@ char    Null[1];
 # else
 # define PROGPATH(name) "/usr/ccs/bin/name"	/* place to find binaries */
 # endif
-# endif XPG4
-# endif DESTDIR
+# endif /* XPG4 */
+# endif /* DESTDIR */
 
-#if	defined(XPROGPATH) && !defined(XPG4)
+#if	defined(INS_BASE) && !defined(XPG4)
 #undef	PROGPATH
 
 # ifdef __STDC__
-#define PROGPATH(name)	XPROGPATH "/ccs/bin/" #name /* place to find binaries */
+#define PROGPATH(name)	INS_BASE "/ccs/bin/" #name /* place to find binaries */
 #else
-error: you need to edit 
 /*
- * With a K&R compiler, you need to edit the following string in case
- * you like to change the install path.
+ * XXX With a K&R compiler, you need to edit the following string in case
+ * XXX you like to change the install path.
  */
 #define PROGPATH(name) "/usr/ccs/bin/name"	/* place to find binaries */
 #endif
-#endif	/* XPROGPATH */
+#endif	/* defined(INS_BASE) && !defined(XPG4) */
 
 
 /****************  End of Configuration Information  ****************/
 
-typedef char	bool;
+/*typedef char	bool;*/
+typedef int	bool;
 # define TRUE	1
 # define FALSE	0
 
 # define bitset(bit, word)	((bool) ((bit) & (word)))
 
+#ifdef	RRR
 static struct sccsprog *lookup();
 static struct p_file *getpfent();
 static int  checkpfent();
@@ -242,6 +239,7 @@ static int  clean();
 static bool isbranch();
 static void putpfent();
 static char* getNsid();
+#endif
 
 struct sccsprog
 {
@@ -258,6 +256,33 @@ struct list_files
 	char			*s_filename;
 };
 
+int main __PR((int argc, char **argv));
+static char *getNsid __PR((char *file, char *user));
+static int command __PR((char **argv, bool forkflag, char *arg0));
+static void get_list_files __PR((struct list_files *listfilesp, char *filename, bool no_sdot));
+static struct sccsprog *lookup __PR((char *name));
+static int callprog __PR((char *progpath, int flags, char **argv, bool forkflag));
+static char *makefile __PR((char *name, const char *in_SccsDir));
+static bool isdir __PR((char *name));
+static bool isfile __PR((char *name));
+static bool safepath __PR((register char *p));
+static int clean __PR((int mode, char **argv));
+static bool isbranch __PR((char *sid));
+static void unedit __PR((char *fn));
+static char *tail __PR((register char *fn));
+static struct p_file *getpfent __PR((FILE *pfp));
+static int checkpfent __PR((struct p_file *pf));
+static char *nextfield __PR((register char *p));
+static void putpfent __PR((register struct p_file *pf, register FILE *f));
+static int  usrerr	__PR((const char *f, ...));
+static void syserr	__PR((const char *f, ...));
+static char *gstrcat __PR((char *to, char *from, unsigned int xlength));
+static char *gstrncat __PR((char *to, char *from, int n, unsigned int xlength));
+static char *gstrcpy __PR((char *to, const char *from, unsigned int xlength));
+static void gstrbotch __PR((const char *str1, const char *str2));
+static void diffs __PR((char *file));
+static char *makegfile __PR((char *name));
+
 
 /* values for sccsoper */
 # define PROG		0	/* call a program */
@@ -308,7 +333,7 @@ static struct sccsprog SccsProg[] =
 	"sccsdiff",	PROG,	REALUSER,		PROGPATH(sccsdiff),
 #else
 	"sccsdiff",	SHELL,	REALUSER,		PROGPATH(sccsdiff),
-#endif V6		
+#endif /* V6 */
 	"edit",		CMACRO,	NO_SDOT,		"get -e",
 	"delget",	CMACRO,	NO_SDOT,
 	   "delta:mysrpd/get:ixbeskcl -t",
@@ -357,11 +382,20 @@ static bool	Debug;			/* turn on tracing */
 # endif
 # ifndef V6
 extern char	*getenv();
-# endif V6
+# endif /* V6 */
 
 #ifdef XPG4
+/*static char path[] = NOGETTEXT("PATH=/usr/xpg4/bin:/usr/ccs/bin:/usr/bin");*/
+#ifdef	PROTOTYPES
+static char path[] = NOGETTEXT("PATH=" INS_BASE "/xpg4/bin:" INS_BASE "/ccs/bin:/usr/bin");
+#else
+/*
+ * XXX With a K&R compiler, you need to edit the following string in case
+ * XXX you like to change the install path.
+ */
 static char path[] = NOGETTEXT("PATH=/usr/xpg4/bin:/usr/ccs/bin:/usr/bin");
 #endif
+#endif
 
 static struct	sccsprog	*maincmd = NULL;
 static struct	sccsprog	*curcmd  = NULL;
@@ -371,10 +405,10 @@ struct  stat 		Statbuf;
 extern char	*sys_siglist[];
 #endif
 
-static char *gstrcat();
-static char *gstrncat();
-static char *gstrcpy();
-static void gstrbotch();
+/*static char *gstrcat();*/
+/*static char *gstrncat();*/
+/*static char *gstrcpy();*/
+/*static void gstrbotch();*/
 extern	int Fcnt;
 
 static int create_macro  = 0;	/* 1 if "sccs create ..."  command is running. */
@@ -406,12 +440,15 @@ main(argc, argv)
  	/* 
  	 * Set directory to search for general l10n SCCS messages.
  	 */
-#ifdef	USE_NLS
+#ifdef	PROTOTYPES
+	bindtextdomain(NOGETTEXT("SUNW_SPRO_SCCS"),
+	   NOGETTEXT(INS_BASE "/ccs/lib/locale/"));
+#else
  	bindtextdomain(NOGETTEXT("SUNW_SPRO_SCCS"),
  	   NOGETTEXT("/usr/ccs/lib/locale/"));
+#endif
  	
  	textdomain(NOGETTEXT("SUNW_SPRO_SCCS"));
-#endif
 
 	Fflags = FTLEXIT | FTLMSG | FTLCLN;
 
@@ -482,8 +519,8 @@ main(argc, argv)
 			SccsDir[strlen(SccsDir) - 2] = '\0';
 		}
 	}
-# endif SCCSDIR
-# endif V6
+# endif /* SCCSDIR */
+# endif /* V6 */
 
 	/*
 	**  Detect and decode flags intended for this program.
@@ -599,7 +636,7 @@ getNsid(file, user)
 		return(NULL);
 	strcpy(Nsid, "");
 	zero((char *)&goodpf, sizeof(goodpf));
-	in = xfopen(cp, O_RDONLY);
+	in = xfopen(cp, O_RDONLY|O_BINARY);
 	while (fgets(line, sizeof(line), in) != NULL) {
 		pf_ab(line, &pf, 1);
 		if (equal(pf.pf_user, user) || getuid()==0) {
@@ -806,9 +843,9 @@ command(argv, forkflag, arg0)
 			 int  nline;
 
 			 nline = 0;
-			 for (cp = ibuf; *cp != NULL; cp++) {
+			 for (cp = ibuf; *cp != '\0'; cp++) {
 				if (*cp == '\n') {
-					*cp = NULL;
+					*cp = '\0';
 					nline = 1;
 					break;
 				}
@@ -824,8 +861,10 @@ command(argv, forkflag, arg0)
 			    dir = readdir(dirf);
 			    dir = readdir(dirf);
 			    while(dir = readdir(dirf)) { 
+#ifdef	HAVE_DIRENT_D_INO
 			       if(dir->d_ino == 0)
 				  continue;
+#endif
 			       str = malloc(BUFSIZ);
 			       if(str == NULL) {
 			          perror(gettext("Sccs: no mem"));
@@ -1123,7 +1162,7 @@ command(argv, forkflag, arg0)
 	  	if (create_macro == 1 && !strcmp(cmd->sccsname, "get")) {
 	  		char Gname[FILESIZE];
 	  		char *  gf;
-	  		int     ind, ind1;
+	  		int     ind, ind1 = 0;
 	  		
 			for (ind = 0; ap[ind] != NULL; ind++) {
 				ind1 = ind;
@@ -1204,9 +1243,9 @@ command(argv, forkflag, arg0)
 
 	  case CMACRO:		/* command macro */
 		{
-		int cnt, ind, xsize, first_part_macro, macro_rval;
-		char **ap1, **next_file;
-		char **cp,  **file_arg;
+		int cnt, ind, xsize, first_part_macro = 0, macro_rval = 0;
+		char **ap1 = NULL, **next_file;
+		char **cp,  **file_arg = NULL;
 
 		/* step through & execute each part of the macro */
 		ap_for_get = NULL;
@@ -1342,7 +1381,7 @@ command(argv, forkflag, arg0)
 	  case FIX:		/* fix a delta */
 	  	{
 	  	int		n = 0, rflag = 0;
-	  	char		*sidp;
+	  	char		*sidp = NULL;
 	  	struct	sid	sid;
 	  	
 		/* find the end of the flag arguments */
@@ -1781,7 +1820,7 @@ callprog(progpath, flags, argv, forkflag)
 	execvp(progpath, argv);
 #else
 	execv(progpath, argv);
-#endif V6		
+#endif /* V6 */
 	syserr(gettext("cannot execute %s"), progpath);
 	exit(EX_UNAVAILABLE);
 	/*NOTREACHED*/
@@ -2146,7 +2185,7 @@ clean(mode, argv)
 		**		entry.
 		*/
 
-		pfp = fopen(buf, "r");
+		pfp = fopen(buf, "rb");
 		gotpfent = FALSE;
 		edited = FALSE;
 		if (pfp != NULL)
@@ -2315,7 +2354,7 @@ unedit(fn)
 	/* turn "s." into "p." & try to open it */
 	*++q = 'p';
 
-	pfp = fopen(pfn, "r");
+	pfp = fopen(pfn, "rb");
 	if (pfp == NULL)
 	{
 		printf(gettext("%12s: not being edited\n"),
@@ -2325,13 +2364,20 @@ unedit(fn)
 
 	/* create temp file for editing p-file */
 	strcpy(tfn, template);
+#ifdef	HAVE_MKSTEMP
+	tfp = fdopen(mkstemp(tfn), "wb");
+#else
 	mktemp(tfn);
-	tfp = fopen(tfn, "w");
+	tfp = fopen(tfn, "wb");
+#endif
 	if (tfp == NULL)
 	{
 		usrerr(gettext("cannot create \"%s\""), tfn);
 		exit(EX_OSERR);
 	}
+#ifdef	NEED_O_BINARY
+	setmode(fileno(tfp), O_BINARY);
+#endif
 
 	/* figure out who I am */
 	myname = logname();
@@ -2399,12 +2445,12 @@ unedit(fn)
 	if (others)
 	{
 		/* copy it back (perhaps it should be linked?) */
-		if (freopen(tfn, "r", tfp) == NULL)
+		if (freopen(tfn, "rb", tfp) == NULL)
 		{
 			syserr(gettext("cannot reopen \"%s\""), tfn);
 			exit(EX_OSERR);
 		}
-		if (freopen(pfn, "w", pfp) == NULL)
+		if (freopen(pfn, "wb", pfp) == NULL)
 		{
 			usrerr(gettext("cannot create \"%s\""), pfn);
 			return;
@@ -2683,7 +2729,8 @@ static char *gstrncat(to, from, n, xlength)
 }
 
 static char *gstrcpy(to, from, xlength)
-	char	*to, *from;
+	char		*to;
+	const char	*from;
 	unsigned	xlength;
 {
 	if (strlen(from) >= xlength) {
@@ -2694,7 +2741,7 @@ static char *gstrcpy(to, from, xlength)
 
 static void
 gstrbotch(str1, str2)
-	char	*str1, *str2;
+	const char	*str1, *str2;
 {
 	usrerr(gettext("Filename(s) too long: %s %s"),
 	       str1,
