@@ -34,7 +34,7 @@
 # include	<had.h>
 # include       <i18n.h>
 # include       <sys/utsname.h>
-# include       <sys/wait.h>
+# include       <schily/wait.h>
 # include       <ctype.h>
 # include       <ccstypes.h>
 
@@ -88,8 +88,13 @@ char *argv[];
 	/* 
 	 * Set directory to search for general l10n SCCS messages.
 	 */
+#ifdef	PROTOTYPES
+	bindtextdomain(NOGETTEXT("SUNW_SPRO_SCCS"),
+	   NOGETTEXT(INS_BASE "/ccs/lib/locale/"));
+#else
 	bindtextdomain(NOGETTEXT("SUNW_SPRO_SCCS"),
 	   NOGETTEXT("/usr/ccs/lib/locale/"));
+#endif
 	
 	textdomain(NOGETTEXT("SUNW_SPRO_SCCS"));
 
@@ -286,7 +291,7 @@ struct sid *sp;
 	name = 0;
 	user = logname();
 	zero((char *)&goodpf,sizeof(goodpf));
-	in = xfopen(auxf(pkt->p_file,'p'),0);
+	in = xfopen(auxf(pkt->p_file,'p'), O_RDONLY|O_BINARY);
 	cp  = auxf(pkt->p_file,'q');
 	out = xfcreat(cp, (mode_t)0644);
 	while (fgets(line,sizeof(line),in) != NULL) {
@@ -359,7 +364,7 @@ struct packet *pkt;
 	int c;
 	FILE *in;
 
-	if(!(in = fopen(auxf(pkt->p_file,'p'),NOGETTEXT("r")))) {
+	if(!(in = fopen(auxf(pkt->p_file,'p'), NOGETTEXT("rb")))) {
 	   if (gpkt.p_verbose && (num_files > 1 || had_dir || had_standinp))
 	      fprintf(stderr,"\n%s:\n",gpkt.p_file);
 	   fatal(gettext("No outstanding deltas"));
