@@ -38,8 +38,6 @@
 /************************************************************************/
 
 # include	<defines.h>
-# include	<schily/utypes.h>
-#include	<schily/standard.h>	/* define signed */
 # include	<had.h>
 # include	<i18n.h>
 # include	<ccstypes.h>
@@ -120,8 +118,13 @@ char	*argv[];
 	/* 
 	 * Set directory to search for general l10n SCCS messages.
 	 */
+#ifdef	PROTOTYPES
+	bindtextdomain(NOGETTEXT("SUNW_SPRO_SCCS"),
+	   NOGETTEXT(INS_BASE "/ccs/lib/locale/"));
+#else
 	bindtextdomain(NOGETTEXT("SUNW_SPRO_SCCS"),
 	   NOGETTEXT("/usr/ccs/lib/locale/"));
+#endif
 	
 	textdomain(NOGETTEXT("SUNW_SPRO_SCCS"));
 
@@ -359,7 +362,7 @@ char	*c_name;
 
 	infile_err = goods = goodt = goodn = hadmflag = 0;
 	s_init(&gpkt,c_path);
-	if (!sccsfile(c_path) || (gpkt.p_iop = fopen(c_path,"r")) == NULL)
+	if (!sccsfile(c_path) || (gpkt.p_iop = fopen(c_path, "rb")) == NULL)
 		infile_err |= FILENAM_ERR;
 	else {
 		l = get_line(&gpkt);		/* read first line in file */
