@@ -66,8 +66,13 @@ register char **argv;
 	/* 
 	 * Set directory to search for general l10n SCCS messages.
 	 */
+#ifdef	PROTOTYPES
+	bindtextdomain(NOGETTEXT("SUNW_SPRO_SCCS"),
+	   NOGETTEXT(INS_BASE "/ccs/lib/locale/"));
+#else
 	bindtextdomain(NOGETTEXT("SUNW_SPRO_SCCS"),
 	   NOGETTEXT("/usr/ccs/lib/locale/"));
+#endif
 	
 	textdomain(NOGETTEXT("SUNW_SPRO_SCCS"));
 
@@ -121,7 +126,7 @@ register char **argv;
 			if(!argv[i]) {
 			   continue;
 			}
-			if ((iop = fopen(argv[i],NOGETTEXT("r"))) == NULL)
+			if ((iop = fopen(argv[i], NOGETTEXT("rb"))) == NULL)
 				fprintf(stderr,gettext("can't open %s (26)\n"),
 					argv[i]);
 			else {
