@@ -35,7 +35,7 @@
 # include	<had.h>
 # include	<i18n.h>
 # include	<sys/utsname.h>
-# include	<sys/wait.h>
+# include	<schily/wait.h>
 # include	<ccstypes.h>
 
 struct stat Statbuf;
@@ -103,7 +103,7 @@ static void	fgetchk __PR((char *file, struct packet *pkt));
 extern int	org_ihash;
 extern int	org_chash;
 extern int	org_uchash;
-extern char *		saveid;
+extern char	saveid[];
 
 int
 main(argc,argv)
@@ -124,8 +124,13 @@ register char *argv[];
 	/* 
 	 * Set directory to search for general l10n SCCS messages.
 	 */
+#ifdef	PROTOTYPES
+	bindtextdomain(NOGETTEXT("SUNW_SPRO_SCCS"),
+	   NOGETTEXT(INS_BASE "/ccs/lib/locale/"));
+#else
 	bindtextdomain(NOGETTEXT("SUNW_SPRO_SCCS"),
 	   NOGETTEXT("/usr/ccs/lib/locale/"));
+#endif
 	
 	textdomain(NOGETTEXT("SUNW_SPRO_SCCS"));
 
@@ -303,7 +308,7 @@ char *file;
 	gpkt.p_reopen = 1;
 	gpkt.p_stdout = stdout;
 	copy(auxf(gpkt.p_file,'g'),gfilename);
-	Gin = xfopen(gfilename, O_RDONLY);
+	Gin = xfopen(gfilename, O_RDONLY|O_BINARY);
 	pp = rdpfile(&gpkt,&sid);
 
 	if((pp->pf_cmrlist)==0)
@@ -374,7 +379,7 @@ char *file;
 		efp = NULL;
 		if (Gin)
 			fclose(Gin);
-		Gin = xfopen(auxf(gpkt.p_file,'e'), O_RDONLY);
+		Gin = xfopen(auxf(gpkt.p_file,'e'), O_RDONLY|O_BINARY);
 	}
 	copy(auxf(gpkt.p_file,'d'),dfilename);
 	gpkt.p_gout = xfcreat(dfilename,(mode_t)0444);
@@ -515,7 +520,7 @@ char *file;
 				/*
 				Re-open s-file.
 				*/
-				gpkt.p_iop = xfopen(gpkt.p_file, O_RDONLY);
+				gpkt.p_iop = xfopen(gpkt.p_file, O_RDONLY|O_BINARY);
 				setbuf(gpkt.p_iop,gpkt.p_buf);
 				/*
 				Reset counters.
@@ -793,13 +798,13 @@ struct sid *sp;
 	if ((user=logname()) == NULL)
 	   fatal(gettext("User ID not in password file (cm9)"));
 	zero((char *)&goodpf,sizeof(goodpf));
-	in = xfopen(auxf(pkt->p_file,'p'), O_RDONLY);
+	in = xfopen(auxf(pkt->p_file,'p'), O_RDONLY|O_BINARY);
 	outname = auxf(pkt->p_file, 'q');
-	if ((fd=open(outname, O_WRONLY|O_CREAT|O_EXCL, 0444)) < 0) {
+	if ((fd=open(outname, O_WRONLY|O_CREAT|O_EXCL|O_BINARY, 0444)) < 0) {
 	   fatal(gettext("cannot create lock file (cm4)"));
 	}
 	fchmod(fd, (mode_t)0644);
-	out = fdfopen(fd, 1);
+	out = fdfopen(fd, O_WRONLY|O_BINARY);
 	while (fgets(line,sizeof(line),in) != NULL) {
 		pf_ab(line,&pf,1);
 		pf.pf_date = cutoff;
@@ -900,7 +905,7 @@ int difflim;
 	}
 	else {
 		close(pfd[1]);
-		iop = fdfopen(pfd[0],0);
+		iop = fdfopen(pfd[0], O_RDONLY|O_BINARY);
 		return(iop);
 	}
 	/*NOTREACHED*/
@@ -1174,7 +1179,7 @@ struct	packet	*pkt;
 	int	nline, index = 0, search_on = 0;
 	char	lastchar;
 
-	inptr = xfopen(file, O_RDONLY);
+	inptr = xfopen(file, O_RDONLY|O_BINARY);
 	/*
 	 * This gives the illusion that a zero-length file ends
 	 * in a newline so that it won't be mistaken for a 
@@ -1226,8 +1231,10 @@ struct	packet	*pkt;
 /* SVR4.0 does not support getdtablesize().				  */
 /* Code should be rewritten using getrlimit() when R_NFILES is available. */
 
+#ifndef	HAVE_GETDTABLESIZE
 int
 getdtablesize()
 {
 	return (15);
 }
+#endif
