@@ -31,9 +31,8 @@
 #ident	"@(#)defines.h"
 #ident	"@(#)sccs:hdr/defines.h"
 # include	<schily/mconfig.h>
-# include	<sys/types.h>
-/*# include	<param.h>*/
-# include	<schily/utypes.h>
+# include	<schily/types.h>
+# include	<schily/param.h>
 # include	<schily/stat.h>
 # include	<schily/errno.h>
 # include	<schily/fcntl.h>
@@ -41,6 +40,7 @@
 # include	<schily/stdlib.h>
 # include	<schily/unistd.h>
 # include	<schily/string.h>
+# include	<schily/standard.h>	/* define signed */
 /*# include	<locale.h>*/
 # include	<schily/nlsdefs.h>
 # include	<macros.h>
@@ -50,8 +50,14 @@
 # include 	"fatal.h"
 
 /*XXXXXXXXXX*/
+#ifdef	HAVE_VAR_TIMEZONE
 extern long timezone;
-#include <sys/timeb.h>
+#else
+#define	timezone	xtimezone
+long	timezone;
+#endif
+#define	tzset		xtzset
+
 extern int optind, opterr, optopt;
 extern char *optarg;
 
@@ -88,6 +94,14 @@ extern char *optarg;
 
 # define NFLAGS	28
 
+#if	defined(IS_MACOS_X)
+/*
+ * Quick and dirty hack to work around a bug in the Mac OS X linker
+ */
+char	*Sflags[NFLAGS];	/* sync with lib/comobj/src/permiss.c */
+char	saveid[50];		/* sync with lib/comobj/src/logname.c */
+#endif
+
 # define FLAG		'f'
 # define NULLFLAG	'n'
 # define JOINTFLAG	'j'
@@ -317,6 +331,7 @@ extern	void	get_Del_Date_time __PR((char *, struct deltab *, struct packet *, st
 extern	char*	stalloc	__PR((unsigned int));
 extern	int	mosize	__PR((int y, int t));
 extern	int	gN	__PR((char *str, char **next, int num, int *digits, int *chars));
+extern	void	xtzset	__PR((void));
 
 /*
  Declares for external functions in lib/mpwlib
@@ -345,7 +360,7 @@ extern	int	imatch	__PR((char *, char *));
 extern	int	xmsg	__PR((const char *, const char *));
 extern	FILE*	fdfopen	__PR((int, int));
 extern	int	xcreat	__PR((char *, mode_t));
-extern	int	xopen	__PR((char [], mode_t));
+extern	int	xopen	__PR((char [], int));
 extern	int	xlink	__PR((const char *, const char *));
 extern	int	xunlink	__PR((const char *));
 extern	int	xpipe	__PR((int *));
@@ -373,7 +388,7 @@ extern	void	enter	__PR((struct packet *pkt, int ch, int n, struct sid *sidp));
 
 # define copy(srce,dest)	cat(dest,srce,0)
 # define xfopen(file,mode)	fdfopen(xopen(file,mode),mode)
-# define xfcreat(file,mode)	fdfopen(xcreat(file,mode),1)
+# define xfcreat(file,mode)	fdfopen(xcreat(file,mode), O_WRONLY|O_BINARY)
 # define remove(file)		xunlink(file)
 # define USXALLOC() \
 		char *alloc(n) {return((char *)xalloc((unsigned)n));} \
