@@ -30,8 +30,8 @@
 
 #ident	"@(#)deltack.c"
 #ident	"@(#)sccs:lib/cassi/deltack.c"
-#include <had.h>
 #include <defines.h>
+#include <had.h>
 #include <filehand.h>
 #include <i18n.h>
 #include <ccstypes.h>
@@ -92,7 +92,7 @@ deltack(pfile,mrs,nsid,apl)
 	strcat(errorlog,NOGETTEXT("LOG"));
 	if(!(mrs))
 		{
-		 if ((efd=fopen(errorlog,"a")) != NULL)
+		 if ((efd=fopen(errorlog, "ab")) != NULL)
 			{fprintf(efd, gettext("***CASSI REPORTS ERROR: no CMRS in pfile: %s\n"), pfile);
 			 (void) fclose(efd);
 			 efd = NULL;
@@ -173,7 +173,7 @@ char *cmrs,*statp,*type,*fred;
 	{
 		if (badflag) /* no legal cmrs in list */
 		{
-		 if ((efd=fopen(errorlog,"a")) != NULL)
+		 if ((efd=fopen(errorlog, "ab")) != NULL)
 		     {fprintf(efd, gettext("***CASSI REPORTS ERROR: no CMRS at sd\n"));
 			 (void) fclose(efd);
 			 efd = NULL;
@@ -371,9 +371,9 @@ msg(syst,name,cmrs,stats,types,sids,fred)
 	 strcat(holdfred,NOGETTEXT("/termLOG"));
 	 if(stat(holdfred,&stbuf) == -1)
 		noexist = 1; /*new termLOG */
-	 if(!(fd=fopen(holdfred,"a")))
+	 if(!(fd=fopen(holdfred, "ab")))
 		{
-		 if ((efd=fopen(errorlog,"a")) != NULL)
+		 if ((efd=fopen(errorlog, "ab")) != NULL)
 		         {fprintf(efd,gettext("***CASSI REPORTS ERROR: can't write to FRED : %s\n"), pname);
 			 (void) fclose(efd);
 			 efd = NULL;
@@ -392,7 +392,7 @@ msg(syst,name,cmrs,stats,types,sids,fred)
 	 {
 		if(stat(dir,&stbuf) == -1)
 		{
-		 if ((efd=fopen(errorlog,"a")) != NULL)
+		 if ((efd=fopen(errorlog, "ab")) != NULL)
 			{fprintf(efd, gettext("***CASSI REPORTS ERROR: can't write to BD/source : %s\n"), pname);
 			 (void) fclose(efd);
 			 efd = NULL;
