@@ -55,8 +55,8 @@ extern FILE		*trace;
 # define TR(W,X,Y,Z) /* W X Y Z */
 # endif
 
-# define READ "r"
-# define APP "a"
+# define READ "rb"
+# define APP "ab"
 # define BUFSIZE 1024
 # define SAME 0							/* Same as strcmp. */
 # define BEFORE 1						/* Almost same as strcmp. */
