@@ -34,7 +34,10 @@
 
 # include	<macros.h>
 #if !(defined(BUG_1205145) || defined(GMT_TIME))
-# include	<time.h>
+/*
+ * time.h is already includes from defines.h
+ */
+/*# include	<time.h>*/
 #endif
 
 /*
@@ -60,11 +63,7 @@ time_t	*bdt;
 	time_t	tim;
 
 #if !(defined(BUG_1205145) || defined(GMT_TIME))
-	struct timeb timeb;
-	ftime(&timeb);
 	tzset();
-	if (timezone == 0)
-		timezone = timeb.timezone * 60; 
 #endif
 	Datep = adt;
 
@@ -148,11 +147,7 @@ time_t	*bdt;
 	int y, t, d, h, m, s, i;
 	time_t	tim;
 
-	struct timeb timeb;
-	ftime(&timeb);
 	tzset();
-	if (timezone == 0)
-		timezone = timeb.timezone * 60; 
 
 	if((y=gN(adt, &adt, 2, NULL, NULL)) == -2) y = 99;
 	if (y<69) y += 100;
@@ -239,3 +234,50 @@ gN(str, next, num, digits, chars)
 
 	return c;
 }
+
+#ifdef	HAVE_FTIME
+#include <sys/timeb.h>
+#endif
+
+void
+xtzset()
+{
+	time_t	t;
+	time_t	t2 = 0;
+	time_t	t3 = 0;
+	struct tm *tm = NULL;
+#ifdef	HAVE_FTIME
+	struct timeb timeb;
+#endif
+
+#ifdef	HAVE_TZSET
+#undef	tzset
+	tzset();
+#endif
+#ifdef	HAVE_VAR_TIMEZONE
+	if (timezone != 0)
+		return;
+#endif
+
+	t = time((time_t *)0);
+#if	defined(HAVE_GMTIME) && defined(HAVE_LOCALTIME) && defined(HAVE_MKTIME)
+	tm = gmtime(&t);
+	t2 = mktime(tm);
+	tm = localtime(&t);
+	t3 = mktime(tm);	/* t3 should be == t */
+#else
+#if	defined(HAVE_GMTIME) && defined(HAVE_TIMELOCAL) && defined(HAVE_TIMEGM)
+	tm = gmtime(&t);
+	t2 = timelocal(tm);
+	t3 = timegm(tm);
+#endif
+#endif
+	timezone = t2 - t3;
+
+#ifdef	HAVE_FTIME
+	if (timezone == 0) {
+		ftime(&timeb);
+		timezone = timeb.timezone * 60;
+	}
+#endif
+}
