@@ -33,7 +33,7 @@
 # include	<defines.h>
 # include	<pwd.h>
 
-char saveid[50];
+char saveid[50];		/* sync with hdr/defines.h */
 char	*logname()
 {
 	struct passwd *log_name;
