@@ -196,7 +196,7 @@ check_permission_SccsDir(path)
 
 	strcpy(dirname, sname(path));
 	strcat(dirname, "/.");
-	if ((desc = open(dirname, O_RDONLY)) < 0) {
+	if ((desc = open(dirname, O_RDONLY|O_BINARY)) < 0) {
 		if (errno == EACCES) {
 			fprintf(stderr, gettext("%s: Permission denied\n"), dname(dirname));
 			++Fcnt;
