@@ -37,7 +37,6 @@
 	NULL on failure (no file structures available).
 */
 
-# include	<stdio.h>
 # include	<defines.h>
 # include	<macros.h>
 
@@ -47,8 +46,11 @@ register int fd, mode;
 {
 	if (fstat(fd, &Statbuf) < 0)
 		return(NULL);
-	if (mode)
-		return(fdopen(fd,"w"));
+	mode &= O_ACCMODE;
+	if (mode == O_WRONLY)
+		return(fdopen(fd,"wb"));
+	else if (mode == O_RDWR)
+		return(fdopen(fd,"rb+"));
 	else
-		return(fdopen(fd,"r"));
+		return(fdopen(fd,"rb"));
 }
