@@ -84,15 +84,15 @@ char	*uuname;
 
 	copy(lockfile, tempfile);
 	sprintf(uniqfilename, "%s/%lu.%s%ld", dname(tempfile),
-	   pid, uuname, time((long *)0));
+	   pid, uuname, time((time_t *)0));
 	if (length(uniqfilename) >= PATH_MAX) {
-	   uniq_nmbr = (int)pid + (int)time((long *)0);   
+	   uniq_nmbr = (int)pid + (int)time((time_t *)0);   
 	   copy(lockfile, tempfile);
 	   sprintf(uniqfilename, "%s/%X", dname(tempfile),
 	      uniq_nmbr&0xffffffff);
 	   uniqfilename[PATH_MAX-1] = '\0';
 	}
-	fd = open(uniqfilename, O_WRONLY|O_CREAT, 0666);
+	fd = open(uniqfilename, O_WRONLY|O_CREAT|O_BINARY, 0666);
         if (fd < 0) {
 	   return(-1);
 	} else {
@@ -105,7 +105,7 @@ char	*uuname;
 		if (!exists(lockfile))
 		   continue;
 		omtime = Statbuf.st_mtime;
-		if ((fd = open(lockfile, O_RDONLY)) < 0)
+		if ((fd = open(lockfile, O_RDONLY|O_BINARY)) < 0)
 		   continue;
 		(void)read(fd, (char *)&opid, sizeof(opid));
 		(void)read(fd, ouuname, nodenamelength);
@@ -120,7 +120,7 @@ char	*uuname;
 		      }
 		   }
 		}
-		if ((ltime = time((long *)0) - Statbuf.st_mtime) < 60L) {
+		if ((ltime = time((time_t *)0) - Statbuf.st_mtime) < 60L) {
 		   if (ltime >= 0 && ltime < 60) {
 		      (void) sleep((unsigned) (60 - ltime));
 		   } else {
@@ -142,7 +142,7 @@ char	*uuname;
 	pid_t	opid;
 	char	ouuname[nodenamelength];
 
-	if ((fd = open(lockfile, O_RDONLY)) < 0) {
+	if ((fd = open(lockfile, O_RDONLY|O_BINARY)) < 0) {
 	   return(-1);
 	}
 	n = read(fd, (char *)&opid, sizeof(opid));
@@ -163,7 +163,7 @@ char	*lockfile;
 {
 	int	fd;
 	
-        if ((fd = open(lockfile, O_WRONLY|O_CREAT|O_EXCL|O_DSYNC, 0444)) >= 0) {
+        if ((fd = open(lockfile, O_WRONLY|O_CREAT|O_EXCL|O_DSYNC|O_BINARY, 0444)) >= 0) {
 	   if (write(fd, (char *)&pid, sizeof(pid)) != sizeof(pid)) {
 	      (void)close(fd);
 	      (void)unlink(lockfile);
@@ -194,7 +194,7 @@ char	*uuname;
 	pid_t	opid;
 	char	ouuname[nodenamelength];
 
-	if ((fd = open(lockfile, O_RDONLY)) < 0)
+	if ((fd = open(lockfile, O_RDONLY|O_BINARY)) < 0)
 	   return(0);
 	n = read(fd, (char *)&opid, sizeof(opid));
 	(void)read(fd, ouuname, nodenamelength);
