@@ -35,12 +35,18 @@
 	Return `str'.
 */
 
+#include <defines.h>
+
+#ifdef	PROTOTYPES
+char *
+repl(char *str, char old, char new)
+#else
 char *
 repl(str,old,new)
 char *str;
 char old,new;
+#endif
 {
-	extern char	*trnslat();
 	char		old_str[2];
 	
 	old_str[0] = old;
