@@ -95,11 +95,15 @@ int sig;
 	static int die = 0;
 	
 	if (die++) {
+#ifdef	SIGIOT
 		signal(SIGIOT,0);
+#endif
 #ifdef	SIGEMT
 		signal(SIGEMT,0);
 #endif
+#ifdef	SIGILL
 		signal(SIGILL,0);
+#endif
 		exit(1);
 	}
 	if (Mesg[sig]) {
@@ -110,12 +114,16 @@ int sig;
 	else
 		signal(sig,SIG_IGN);
 	clean_up();
-	if(open(NOGETTEXT("dump.core"), 0) > 0) {
+	if(open(NOGETTEXT("dump.core"), O_RDONLY|O_BINARY) > 0) {
+#ifdef	SIGIOT
 		signal(SIGIOT,0);
+#endif
 #ifdef	SIGEMT
 		signal(SIGEMT,0);
 #endif
+#ifdef	SIGILL
 		signal(SIGILL,0);
+#endif
 		abort();
 	}
 	exit(userexit(1));
