@@ -36,12 +36,8 @@
 	fatal() on failure.
 */
 
-# include	<schily/mconfig.h>
-# include	<schily/errno.h>
-# include	<schily/nlsdefs.h>
-# include       <i18n.h>
-/*# include       <locale.h>*/
 # include       <defines.h>
+# include       <i18n.h>
 
 int
 xlink(f1,f2)
