@@ -37,18 +37,14 @@
 	fatal() on failure.
 */
 
-# include <errno.h>
-# include <fcntl.h>
+# include <defines.h>
 # include <i18n.h>
 # include <ccstypes.h>
-# include <schily/nlsdefs.h>
-/*# include <locale.h>*/
-# include <defines.h>
 
 int
 xopen(name,mode)
 char name[];
-mode_t mode;
+int mode;
 {
 	register int fd;
 	extern char SccsError[];
