@@ -31,10 +31,12 @@
 #ident	"@(#)xpipe.c"
 #ident	"@(#)sccs:lib/mpwlib/xpipe.c"
 
-#include <schily/mconfig.h>
-#include <i18n.h>
-#include <string.h>
 #include <defines.h>
+#include <i18n.h>
+
+#ifdef	NEED_O_BINARY
+#include <io.h>			/* for setmode() prototype */
+#endif
 
 
 /*
@@ -57,5 +59,9 @@ int *t;
 	strcpy(p, (const char *) NOGETTEXT("pipe"));
 	if (pipe(t) == 0)
 		return(0);
+#ifdef	NEED_O_BINARY
+	setmode(t[0], O_BINARY);
+	setmode(t[1], O_BINARY);
+#endif
 	return(xmsg(p,p));
 }
