@@ -31,7 +31,7 @@
 #ident	"@(#)ccstypes.h"
 #ident	"@(#)sgs-inc:common/ccstypes.h"
 
-#include <schily/utypes.h>
+#include <schily/types.h>
 
 #ifdef	never
 #ifndef _SYS_TYPES_H
